# EXAMPLES OF PRIOR INFORMATION TRANSFER USING ANNEALED IMPORTNCE SAMPLING.
#
# Written by Radford M. Neal, July 2001.
#
# This continues the example of cont-ex.r by trying out the annealed 
# importance sampling method with Gibbs sampling done at each stage.
# The results can be compared to those found with simple Monte Carlo.
#
# The log-exp.r, cont.r, and cont-ex.r files must be executed before this one.


# COMPUTATIONS FOR DONOR-WEIGHTED PRIORS.

set.seed(2)

e1.dw.fin.10.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "donor", k=10, N=50, alpha=seq(0.0005,0.9995,0.0005))

e1.dw.fin.50.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "donor", k=50, N=50, alpha=seq(0.0005,0.9995,0.0005))

e1.dw.fin.100.50.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "donor", k=100, mass=50, N=50, alpha=seq(0.0005,0.9995,0.0005))


# COMPUTATIONS FOR JOINTLY-WEIGHTED PRIORS.

# First, investigate computation of the normalization constant for the prior, 
# by two ways using simple Monte Carlo, and by annealed importance sampling.

set.seed(3)

e1.jw.norm.10.r <- cont.jw.norm.r (e1.rpr, e1.dpr1, e1.dpr2, 10, N=20000)
e1.jw.norm.10.d <- cont.jw.norm.d (e1.rpr, e1.dpr1, e1.dpr2, 10, N=20000)

e1.jw.norm.10.ais <- cont.jw.norm.ais (e1.rpr, e1.dpr1, e1.dpr2, 10, 
   N=20, omega=10*seq(0,0.9999,0.0001))

e1.jw.norm.20.r <- cont.jw.norm.r (e1.rpr, e1.dpr1, e1.dpr2, 20, N=200000)
e1.jw.norm.20.d <- cont.jw.norm.d (e1.rpr, e1.dpr1, e1.dpr2, 20, N=200000)

e1.jw.norm.20.ais <- cont.jw.norm.ais (e1.rpr, e1.dpr1, e1.dpr2, 20, 
   N=20, omega=20*seq(0,0.9999,0.0001))

# Try jointly-weighted priors with finite k.

set.seed(4)

e1.jw.fin.10.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "jointly", k=10, N=50,
       alpha=seq(0.0005,0.9995,0.0005),
       omega=10*seq(0,0.9995,0.0005))

e1.jw.fin.20.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "jointly", k=20, N=50,
       alpha=seq(0.0005,0.9995,0.0005),
       omega=20*seq(0,0.9995,0.0005))

e1.jw.fin.50.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "jointly", k=50, N=50,
       alpha=seq(0.0001,0.9999,0.0001),
       omega=50*seq(0,0.9999,0.0001))

# Try jointly-weighted priors with infinite k.

set.seed(5)

e1.jw.inf.10.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "jointly", mass=10, N=50,
       alpha=seq(0.0005,0.9995,0.0005),
       omega=10*seq(0,0.995,0.005))

e1.jw.inf.20.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "jointly", mass=20, N=50,
       alpha=seq(0.0005,0.9995,0.0005),
       omega=20*seq(0,0.995,0.005))

e1.jw.inf.50.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "jointly", mass=50, N=50,
       alpha=seq(0.0001,0.9999,0.0001),
       omega=50*seq(0,0.999,0.001))

set.seed(6)

e1.jw.inf.100.ais <- cont.pit.ais (e1.data, e1.rpr, e1.dpr1, e1.dpr2,
       "jointly", mass=100, N=50,
       alpha=seq(0.000025,0.999975,0.000025),
       omega=100*seq(0,0.999975,0.000025))
