# EXAMPLES OF PRIOR INFORMATION TRANSFER FOR SEWELL AND SHAH'S DATA.
#
# Written by Radford M. Neal, July 2001.
#
# This is Example 2 in my paper on "Transferring prior information between
# models using imaginary data".  All the variables are prefixed by "e2",
# for "example 2".  
#
# The log-exp.r and graph.r files must be executed before this one.


# READ THE DATA.
#                  1    2    3    4    5
# Variable order:  sex  ses  iq   pe   cp

e2.keep.cp <- F     # Should the CP variable be kept?

e2.dat   <- read.table("../ss.dat",head=T)

if (!e2.keep.cp) e2.dat$cp <- NULL

e2.tbl   <- table(e2.dat)
e2.nvals <- prod(dim(e2.tbl))


# BASE FOR PRO FORMA DIRICHLET PRIORS.  Note that the dirichlet paramater
# e2.alpha has nothing to do with the other alphas!

e2.conc <- 120
e2.alpha <- rep(e2.conc/e2.nvals,e2.nvals)
dim(e2.alpha) <- dim(e2.tbl)


# FIND MARGINAL LIKELIHOODS FOR INITIAL MODELS.

e2.ml.a <- graph.ml.a (e2.alpha, e2.tbl)
e2.ml.b <- graph.ml.b (e2.alpha, e2.tbl)


# FIND MARGINAL LIKELIHOODS USING PRIOR INFORMATION TRANSFER WITH SIMPLE MC.

set.seed(1)

e2.dw.aa.10 <- graph.pit.smc (graph.gen.a, graph.ml.a, "donor", k=10, N=20000)
e2.dw.bb.10 <- graph.pit.smc (graph.gen.b, graph.ml.b, "donor", k=10, N=20000)

e2.dw.ba.10 <- graph.pit.smc (graph.gen.b, graph.ml.a, "donor", k=10, N=20000)
e2.dw.ab.10 <- graph.pit.smc (graph.gen.a, graph.ml.b, "donor", k=10, N=20000)

e2.jw.ba.10 <- graph.pit.smc (graph.gen.b, graph.ml.a, "jointly", k=10, N=30000)
e2.jw.ab.10 <- graph.pit.smc (graph.gen.a, graph.ml.b, "jointly", k=10, N=30000)

set.seed(2)

e2.dw.ba.50 <- graph.pit.smc (graph.gen.b, graph.ml.a, "donor", k=50, N=20000)
e2.dw.ab.50 <- graph.pit.smc (graph.gen.a, graph.ml.b, "donor", k=50, N=20000)

e2.jw.ba.50 <- graph.pit.smc (graph.gen.b, graph.ml.a, "jointly", k=50, N=30000)
e2.jw.ab.50 <- graph.pit.smc (graph.gen.a, graph.ml.b, "jointly", k=50, N=30000)

set.seed(3)

e2.dw.ba.inf.50 <- 
  graph.pit.smc (graph.gen.b, graph.ml.a, "donor", mass=50, N=20000)

e2.dw.ab.inf.50 <- 
  graph.pit.smc (graph.gen.a, graph.ml.b, "donor", mass=50, N=20000)

e2.jw.ba.inf.50 <- 
  graph.pit.smc (graph.gen.b, graph.ml.a, "jointly", mass=50, N=30000)

e2.jw.ab.inf.50 <- 
  graph.pit.smc (graph.gen.a, graph.ml.b, "jointly", mass=50, N=30000)

set.seed(4)

e2.dw.ba.inf.100 <- 
  graph.pit.smc (graph.gen.b, graph.ml.a, "donor", mass=100, N=30000)

e2.dw.ab.inf.100 <- 
  graph.pit.smc (graph.gen.a, graph.ml.b, "donor", mass=100, N=30000)

e2.jw.ba.inf.100 <- 
  graph.pit.smc (graph.gen.b, graph.ml.a, "jointly", mass=100, N=45000)

e2.jw.ab.inf.100 <- 
  graph.pit.smc (graph.gen.a, graph.ml.b, "jointly", mass=100, N=45000)


# FIND MARGINAL LIKELIHOODS USING JOINTLY-WEIGHTED TRANSFER WITH ANN IMP SAMP.

set.seed(11)

e2.jw.ba.10.ais <- 
  graph.jw.ais (graph.gen.b, graph.gen.a, k=10, N=20,
  alpha=exp(seq(-10,-0.001,0.001)), 
  omega=10*seq(0,0.9999,0.0001))

e2.jw.ab.10.ais <- 
  graph.jw.ais (graph.gen.a, graph.gen.b, k=10, N=20,
  alpha=exp(seq(-10,-0.001,0.001)), 
  omega=10*seq(0,0.9999,0.0001))

set.seed(12)

e2.jw.ba.50.ais <- 
  graph.jw.ais (graph.gen.b, graph.gen.a, k=50, N=20,
  alpha=exp(seq(-10,-0.001,0.001)), 
  omega=50*seq(0,0.9999,0.0001))

e2.jw.ab.50.ais <- 
  graph.jw.ais (graph.gen.a, graph.gen.b, k=50, N=20,
  alpha=exp(seq(-10,-0.001,0.001)), 
  omega=50*seq(0,0.9999,0.0001))

set.seed(13)

e2.jw.ba.inf.50.ais <- 
  graph.jw.ais (graph.gen.b, graph.gen.a, mass=50, N=20,
  alpha=exp(seq(-8,-0.002,0.002)), 
  omega=50*seq(0,0.995,0.005))

e2.jw.ab.inf.50.ais <- 
  graph.jw.ais (graph.gen.a, graph.gen.b, mass=50, N=20,
  alpha=exp(seq(-8,-0.002,0.002)), 
  omega=50*seq(0,0.999,0.005))


# FIND MARGINAL LIKELIHOODS USING DONOR-WEIGHTED TRANSFER WITH ANN IMP SAMP.

set.seed(21)

e2.dw.ba.10.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, k=10, N=10,
  alpha=exp(seq(-8,-0.002,0.002)))

e2.dw.ab.10.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, k=10, N=10,
  alpha=exp(seq(-8,-0.002,0.002)))

set.seed(22)

e2.dw.ba.50.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, k=50, N=10,
  alpha=exp(seq(-8,-0.002,0.002)))

e2.dw.ab.50.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, k=50, N=10,
  alpha=exp(seq(-8,-0.002,0.002)))

set.seed(23)

e2.dw.ba.inf.50.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=50, N=10,
  alpha=exp(seq(-8,-0.002,0.002))) 

e2.dw.ab.inf.50.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=50, N=10,
  alpha=exp(seq(-8,-0.002,0.002))) 

set.seed(24)

e2.dw.ba.inf.100.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=100, N=10,
  alpha=exp(seq(-8,-0.002,0.002))) 

e2.dw.ab.inf.100.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=100, N=10,
  alpha=exp(seq(-8,-0.002,0.002)))

set.seed(25)

e2.dw.ba.inf.200.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=200, N=10,
  alpha=exp(seq(-8,-0.001,0.001))) 

e2.dw.ab.inf.200.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=200, N=10,
  alpha=exp(seq(-8,-0.001,0.001)))

set.seed(26)

e2.dw.ba.inf.400.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=400, N=10,
  alpha=exp(seq(-8,-0.0005,0.0005))) 

e2.dw.ab.inf.400.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=400, N=10,
  alpha=exp(seq(-8,-0.0005,0.0005)))

set.seed(27)

e2.dw.ba.inf.800.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=800, N=10,
  alpha=exp(seq(-8,-0.0005,0.0005))) 

e2.dw.ab.inf.800.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=800, N=10,
  alpha=exp(seq(-8,-0.0005,0.0005)))

set.seed(30)

e2.dw.ba.inf.1200.ais <- 
  graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=1200, N=10,
  alpha=exp(seq(-8,-0.0005,0.0005))) 

e2.dw.ab.inf.1200.ais <- 
  graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=1200, N=10,
  alpha=exp(seq(-8,-0.0005,0.0005)))

set.seed(28)

e2.dw.ba.inf.1600.ais <- 
 graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=1600, N=10,
 alpha=exp(seq(-8,-0.0005,0.0005))) 

e2.dw.ab.inf.1600.ais <- 
 graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=1600, N=10,
 alpha=exp(seq(-8,-0.0005,0.0005)))

set.seed(29)

e2.dw.ba.inf.3200.ais <- 
 graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=3200, N=10,
 alpha=exp(seq(-8,-0.00025,0.00025))) 

e2.dw.ab.inf.3200.ais <- 
 graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=3200, N=10,
 alpha=exp(seq(-8,-0.00025,0.00025)))

set.seed(31)

e2.dw.ba.inf.6400.ais <- 
 graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=6400, N=5,
 alpha=exp(c(seq(-8,-4.0005,0.0005),seq(-4,-0.00008,0.00008)))) 

set.seed(32)

e2.dw.ab.inf.6400.ais <- 
 graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=6400, N=5,
 alpha=exp(c(seq(-8,-4.0005,0.0005),seq(-4,-0.00008,0.00008)))) 

set.seed(39)

e2.dw.ba.inf.1e6.ais <- 
 graph.dw.ais2 (graph.gen.part.b, graph.comb.pr.b, graph.ml.a, mass=1e6, N=5,
 alpha=exp(c(seq(-8,-5.0005,0.0005),seq(-5,-0.0001,0.0001)))) 

e2.dw.ab.inf.1e6.ais <- 
 graph.dw.ais2 (graph.gen.part.a, graph.comb.pr.a, graph.ml.b, mass=1e6, N=5,
 alpha=exp(c(seq(-8,-5.0005,0.0005),seq(-5,-0.0001,0.0001)))) 


# COMPUTE MARGINAL LIKELIHOODS AVERAGED OVER UNIFORM PRIOR FOR OMEGA VALUES.

e2.dw.ab.average.ml <- log.add.exp (e2.ml.b,
  e2.dw.ab.inf.50.ais$ml,
  e2.dw.ab.inf.100.ais$ml,
  e2.dw.ab.inf.200.ais$ml,
  e2.dw.ab.inf.400.ais$ml,
  e2.dw.ab.inf.800.ais$ml,
  e2.dw.ab.inf.1600.ais$ml,
  e2.dw.ab.inf.3200.ais$ml,
  e2.dw.ab.inf.6400.ais$ml) - log(9)

e2.dw.ba.average.ml <- log.add.exp (e2.ml.a,
  e2.dw.ba.inf.50.ais$ml,
  e2.dw.ba.inf.100.ais$ml,
  e2.dw.ba.inf.200.ais$ml,
  e2.dw.ba.inf.400.ais$ml,
  e2.dw.ba.inf.800.ais$ml,
  e2.dw.ba.inf.1600.ais$ml,
  e2.dw.ba.inf.3200.ais$ml,
  e2.dw.ba.inf.6400.ais$ml) - log(9)
